@@ -1,7 +1,7 @@
 // This module defines the "official" high-level API of the Qt port of
 // Scintilla.
 //
-// Copyright (c) 2004
+// Copyright (c) 2005
 // 	Riverbank Computing Limited <info@riverbankcomputing.co.uk>
 // 
 // This file is part of QScintilla.
@@ -101,6 +101,21 @@ public:
 		SloppyBraceMatch
 	};
 
+	//! This enum defines the different edge modes for long lines.
+	enum EdgeMode {
+		//! Long lines are not marked.
+		EdgeNone = EDGE_NONE,
+
+		//! A vertical line is drawn at the column set by
+		//! setEdgeColumn().  This is recommended for monospace fonts.
+		EdgeLine = EDGE_LINE,
+
+		//! The background color of characters after the column limit
+		//! is changed to the color set by setEdgeColor().  This is
+		//! recommended for proportional fonts.
+		EdgeBackground = EDGE_BACKGROUND
+	};
+
 	//! This enum defines the different end-of-line modes.
 	enum EolMode {
 		//! A carriage return/line feed as used on Windows systems.
@@ -329,6 +344,23 @@ public:
 	//! \sa beginUndoAction(), undo()
 	void endUndoAction();
 
+	//! Returns the color of the marker used to show that a line has
+	//! exceeded the length set by setEdgeColumn().
+	//!
+	//! \sa setEdgeColor(), \sa setEdgeColumn
+	QColor edgeColor();
+
+	//! Returns the number of the column after which lines are considered
+	//! to be long.
+	//!
+	//! \sa setEdgeColumn()
+	int edgeColumn();
+
+	//! Returns the edge mode which determines how long lines are marked.
+	//!
+	//! \sa setEdgeMode()
+	EdgeMode edgeMode();
+
 	//! Returns the end-of-line mode.
 	//!
 	//! \sa setEolMode()
@@ -362,10 +394,13 @@ public:
 	//! search begins from the current cursor position.  Otherwise the
 	//! search begins at position \a index of line \a line.
 	//!
+	//! If \a show is TRUE (the default) then any text found is made
+	//! visible (ie. it is unfolded).
+	//!
 	//! \sa findNext(), replace()
 	virtual bool findFirst(const QString &expr,bool re,bool cs,bool wo,
 			       bool wrap,bool forward = TRUE,int line = -1,
-			       int index = -1);
+			       int index = -1,bool show = TRUE);
 
 	//! Find the next occurence of the string found using findFirst().
 	//!
@@ -642,6 +677,23 @@ public:
 	//! \sa document()
 	void setDocument(const QextScintillaDocument &document);
 
+	//! Set the color of the marker used to show that a line has exceeded
+	//! the length set by setEdgeColumn().
+	//!
+	//! \sa edgeColor(), \sa setEdgeColumn
+	void setEdgeColor(const QColor &col);
+
+	//! Set the number of the column after which lines are considered to be
+	//! long.
+	//!
+	//! \sa edgeColumn()
+	void setEdgeColumn(int colnr);
+
+	//! Set the edge mode which determines how long lines are marked.
+	//!
+	//! \sa edgeMode()
+	void setEdgeMode(EdgeMode mode);
+
 	//! Set the background colour of marker \a mnr to \a col.  If \a mnr is
 	//! -1 then the colour of all markers is set.  The default is white.
 	//!
@@ -715,6 +767,11 @@ public:
 	//! \sa setWhitespaceVisibility()
 	WhitespaceVisibility whitespaceVisibility();
 
+	//! Returns the line wrap mode.
+	//!
+	//! \sa setWrapMode()
+	WrapMode wrapMode();
+
 public slots:
 	//! Appends the text \a text to the end of the text edit.  Note that
 	//! the undo/redo history is cleared by this function.
@@ -775,6 +832,10 @@ public slots:
 	//! \sa unindent()
 	virtual void indent(int line);
 
+	//! Insert the text \a text at the current position.  The new current
+	//! position if after the inserted text.
+	virtual void insert(const QString &text);
+
 	//! Insert the text \a text in the line \a line at the position
 	//! \a index.
 	virtual void insertAt(const QString &text,int line,int index);
@@ -797,6 +858,16 @@ public slots:
 	//! Removes any selected text.
 	virtual void removeSelectedText();
 
+	//! Resets the background colour of selected text to the default.
+	//!
+	//! \sa setSelectionBackgroundColor(), resetSelectionForegroundColor()
+	virtual void resetSelectionBackgroundColor();
+
+	//! Resets the foreground colour of selected text to the default.
+	//!
+	//! \sa setSelectionForegroundColor(), resetSelectionBackgroundColor()
+	virtual void resetSelectionForegroundColor();
+
 	//! If \a select is TRUE (the default) then all the text is selected.
 	//! If \a select is FALSE then any currently selected text is
 	//! deselected.
@@ -1014,12 +1085,12 @@ public slots:
 
 	//! Sets the background colour of selected text to \a col.
 	//!
-	//! \sa setSelectionForegroundColor()
+	//! \sa resetSelectionBackgroundColor(), setSelectionForegroundColor()
 	virtual void setSelectionBackgroundColor(const QColor &col);
 
 	//! Sets the foreground colour of selected text to \a col.
 	//!
-	//! \sa setSelectionBackgroundColor()
+	//! \sa resetSelectionForegroundColor(), setSelectionBackgroundColor()
 	virtual void setSelectionForegroundColor(const QColor &col);
 
 	//! If \a indent is TRUE then the tab key will indent a line rather
@@ -1051,6 +1122,12 @@ public slots:
 	//! \sa whitespaceVisibility()
 	virtual void setWhitespaceVisibility(WhitespaceVisibility mode);
 
+	//! Sets the line wrap mode to mode \a mode.  The default is that lines
+	//! are not wrapped.
+	//!
+	//! \sa wrapMode()
+	virtual void setWrapMode(WrapMode mode);
+
 	//! Undo the last change or sequence of changes.
 	//!
 	//! Scintilla has multiple level undo and redo.  It will continue to
@@ -1217,6 +1294,7 @@ private:
 		int flags;
 		long startpos;
 		long endpos;
+		bool show;
 	};
 
 	FindState findState;
@@ -1240,6 +1318,7 @@ private:
 	QString ctWordList;
 	QextScintillaCommandSet *stdCmds;
 	QextScintillaDocument doc;
+	bool modified;
 
 #if defined(Q_DISABLE_COPY)
 	QextScintilla(const QextScintilla &);
