@@ -1,6 +1,6 @@
 // This class defines the "official" low-level API.
 //
-// Copyright (c) 2004
+// Copyright (c) 2005
 // 	Riverbank Computing Limited <info@riverbankcomputing.co.uk>
 // 
 // This file is part of QScintilla.
@@ -825,6 +825,18 @@ public:
 		//!
 		SCI_CALLTIPSETFOREHLT = 2207,
 
+		//!
+		SCI_AUTOCSETMAXWIDTH = 2208,
+
+		//!
+		SCI_AUTOCGETMAXWIDTH = 2209,
+
+		//!
+		SCI_AUTOCSETMAXHEIGHT = 2210,
+
+		//!
+		SCI_AUTOCGETMAXHEIGHT = 2211,
+
 		//!
 		SCI_VISIBLEFROMDOCLINE = 2220,
 
@@ -870,6 +882,9 @@ public:
 		//!
 		SCI_ENSUREVISIBLEENFORCEPOLICY = 2234,
 
+		//!
+		SCI_WRAPCOUNT = 2235,
+
 		//!
 		SCI_SETTABINDENTS = 2260,
 
@@ -1420,6 +1435,18 @@ public:
 		//!
 		SCI_LINECOPY = 2455,
 
+		//!
+		SCI_FINDCOLUMN = 2456,
+
+		//!
+		SCI_GETCARETSTICKY = 2457,
+
+		//!
+		SCI_SETCARETSTICKY = 2458,
+
+		//!
+		SCI_TOGGLECARETSTICKY = 2459,
+
 		//!
 		SCI_SETWRAPVISUALFLAGS = 2460,
 
@@ -1468,6 +1495,18 @@ public:
 		//! \a wParam is unused.
 		//! \a lParam is the name of the lexer.
 		SCI_SETLEXERLANGUAGE = 4006,
+
+		//!
+		SCI_LOADLEXERLIBRARY = 4007,
+
+		//!
+		SCI_GETPROPERTY = 4008,
+
+		//!
+		SCI_GETPROPERTYEXPANDED = 4009,
+
+		//!
+		SCI_GETPROPERTYINT = 4010,
 	};
 
 	enum
@@ -1602,6 +1641,9 @@ public:
 		//! An XPM format pixmap.
 		SC_MARK_PIXMAP = 25,
 
+		//! A full rectangle.
+		SC_MARK_FULLRECT = 26,
+
 		//! Characters can be used as symbols by adding this to the
 		//! ASCII value of the character.
 		SC_MARK_CHARACTER = 10000
@@ -1664,7 +1706,8 @@ public:
 		SC_CHARSET_HEBREW = 177,
 		SC_CHARSET_ARABIC = 178,
 		SC_CHARSET_VIETNAMESE = 163,
-		SC_CHARSET_THAI = 222
+		SC_CHARSET_THAI = 222,
+		SC_CHARSET_8859_15 = 1000,
 	};
 
 	enum
@@ -1738,7 +1781,8 @@ public:
 	enum
 	{
 		SC_WRAP_NONE = 0,
-		SC_WRAP_WORD = 1
+		SC_WRAP_WORD = 1,
+		SC_WRAP_CHAR = 2
 	};
 
 	enum
@@ -1785,11 +1829,13 @@ public:
 		SC_PERFORMED_USER = 0x10,
 		SC_PERFORMED_UNDO = 0x20,
 		SC_PERFORMED_REDO = 0x40,
+		SC_MULTISTEPUNDOREDO = 0x80,
 		SC_LASTSTEPINUNDOREDO = 0x100,
 		SC_MOD_CHANGEMARKER = 0x200,
 		SC_MOD_BEFOREINSERT = 0x400,
 		SC_MOD_BEFOREDELETE = 0x800,
-		SC_MODEVENTMASKALL = 0xf77
+		SC_MULTILINEUNDOREDO = 0x1000,
+		SC_MODEVENTMASKALL = 0x1fff
 	};
 
 	enum
@@ -1918,10 +1964,10 @@ public:
 		SCLEX_VBSCRIPT = 28,
 
 		//! Select the ASP lexer.
-		SCLEX_ASP = 29,
+		SCLEX_ASP = SCLEX_HTML,
 
 		//! Select the PHP lexer.
-		SCLEX_PHP = 30,
+		SCLEX_PHP = SCLEX_HTML,
 
 		//! Select the Baan lexer.
 		SCLEX_BAAN = 31,
@@ -2018,6 +2064,42 @@ public:
 
 		//! Select the Bash lexer.
 		SCLEX_BASH = 62,
+
+		//! Select the ASN.1 lexer.
+		SCLEX_ASN1 = 63,
+
+		//! Select the VHDL lexer.
+		SCLEX_VHDL = 64,
+
+		//! Select the Caml lexer.
+		SCLEX_CAML = 65,
+
+		//! Select the BlitzBasic lexer.
+		SCLEX_BLITZBASIC = 66,
+
+		//! Select the PureBasic lexer.
+		SCLEX_PUREBASIC = 67,
+
+		//! Select the Haskell lexer.
+		SCLEX_HASKELL = 68,
+
+		//! Select the PHPScript lexer.
+		SCLEX_PHPSCRIPT = 69,
+
+		//! Select the TADS3 lexer.
+		SCLEX_TADS3 = 70,
+
+		//! Select the REBOL lexer.
+		SCLEX_REBOL = 71,
+
+		//! Select the Smalltalk lexer.
+		SCLEX_SMALLTALK = 72,
+
+		//! Select the FlagShip lexer.
+		SCLEX_FLAGSHIP = 73,
+
+		//! Select the Csound lexer.
+		SCLEX_CSOUND = 74,
 	};
 
 	//! Construct an empty QextScintillaBase with parent \a parent, name
@@ -2083,12 +2165,24 @@ public:
 	//! Returns the recommended size of the widget.
 	virtual QSize sizeHint() const;
 
+	//! Returns the viewport widget.  This is the widget that actually
+	//! contains the text.
+	QWidget *viewport() const;
+
 signals:
 	//! This signal is emitted when text is selected or de-selected.
 	//! \a yes is TRUE if text has been selected and FALSE if text has been
 	//! deselected.
 	void QSCN_SELCHANGED(bool yes);
 
+	//! This signal is emitted when the user selects an item in an
+	//! auto-completion list.  It is emitted before the selection is
+	//! inserted.  The insertion can be cancelled by sending an
+	//! SCI_AUTOCANCEL message from a connected slot.
+	//! \a position is the start position of the word being completed.
+	//! \a selection is the text of the selection.
+	void SCN_AUTOCSELECTION(const char *selection,int position);
+
 	//! This signal is emitted when the document has changed for any
 	//! reason.
 	void SCEN_CHANGE();
@@ -2204,6 +2298,9 @@ protected:
 	//! Re-implemented to allow tabs to be entered as text.
 	virtual bool focusNextPrevChild(bool);
 
+	//! Start a drag operation.
+	virtual void startDrag();
+
 private slots:
 	void handleTimer();
 	void handleVSb(int value);
