@@ -1,6 +1,6 @@
 // This defines the interface to the QextScintillaCommandSet class.
 //
-// Copyright (c) 2004
+// Copyright (c) 2005
 // 	Riverbank Computing Limited <info@riverbankcomputing.co.uk>
 // 
 // This file is part of QScintilla.
@@ -57,7 +57,13 @@ public:
 	bool writeSettings(QSettings &qs,const char *prefix = "/Scintilla");
 
 	//! The commands in the set are returned as a list.
-	const QPtrList<QextScintillaCommand> &commands() const {return cmds;}
+	QPtrList<QextScintillaCommand> &commands() {return cmds;}
+
+	//! The primary keys bindings for all commands are removed.
+	void clearKeys();
+
+	//! The alternate keys bindings for all commands are removed.
+	void clearAlternateKeys();
 
 private:
 	friend class QextScintilla;
