@@ -1,35 +1,4 @@
 <!DOCTYPE TS><TS>
-<context>
-    <name>ContextMenu</name>
-    <message>
-        <source>Undo</source>
-        <translation type="obsolete">Rückgängig</translation>
-    </message>
-    <message>
-        <source>Redo</source>
-        <translation type="obsolete">Wiederherstellen</translation>
-    </message>
-    <message>
-        <source>Cut</source>
-        <translation type="obsolete">Ausschneiden</translation>
-    </message>
-    <message>
-        <source>Copy</source>
-        <translation type="obsolete">Kopieren</translation>
-    </message>
-    <message>
-        <source>Paste</source>
-        <translation type="obsolete">Einfügen</translation>
-    </message>
-    <message>
-        <source>Delete</source>
-        <translation type="obsolete">Löschen</translation>
-    </message>
-    <message>
-        <source>Select All</source>
-        <translation type="obsolete">Alles auswählen</translation>
-    </message>
-</context>
 <context>
     <name>QextScintillaCommand</name>
     <message>
@@ -68,10 +37,6 @@
         <source>Move to first visible character in line</source>
         <translation>Zum ersten sichtbaren Zeichen</translation>
     </message>
-    <message>
-        <source>Move to start of line</source>
-        <translation type="obsolete">Zum Beginn der Zeile</translation>
-    </message>
     <message>
         <source>Move to end of line</source>
         <translation>Zum Ende der Zeile</translation>
@@ -337,24 +302,102 @@
         <translation>Seitenumbruch</translation>
     </message>
 </context>
+<context>
+    <name>QextScintillaLexerBash</name>
+    <message>
+        <source>Default</source>
+        <translation>Standard</translation>
+    </message>
+    <message>
+        <source>Error</source>
+        <translation>Fehler</translation>
+    </message>
+    <message>
+        <source>Comment</source>
+        <translation>Kommentar</translation>
+    </message>
+    <message>
+        <source>Number</source>
+        <translation>Zahl</translation>
+    </message>
+    <message>
+        <source>Keyword</source>
+        <translation>Schlüsselwort</translation>
+    </message>
+    <message>
+        <source>Double-quoted string</source>
+        <translation>Zeichenkette in Anführungszeichen</translation>
+    </message>
+    <message>
+        <source>Single-quoted string</source>
+        <translation>Zeichenkette in Hochkommata</translation>
+    </message>
+    <message>
+        <source>Operator</source>
+        <translation>Operator</translation>
+    </message>
+    <message>
+        <source>Identifier</source>
+        <translation>Bezeichner</translation>
+    </message>
+    <message>
+        <source>Scalar</source>
+        <translation>Skalar</translation>
+    </message>
+    <message>
+        <source>Parameter expansion</source>
+        <translation>Parametererweiterung</translation>
+    </message>
+    <message>
+        <source>Backticks</source>
+        <translation>Backticks</translation>
+    </message>
+    <message>
+        <source>Here document delimiter</source>
+        <translation>Here Dokument-Begrenzer</translation>
+    </message>
+    <message>
+        <source>Single-quoted here document</source>
+        <translation>Here Dokument in Hochkommata</translation>
+    </message>
+</context>
+<context>
+    <name>QextScintillaLexerBatch</name>
+    <message>
+        <source>Default</source>
+        <translation>Standard</translation>
+    </message>
+    <message>
+        <source>Comment</source>
+        <translation>Kommentar</translation>
+    </message>
+    <message>
+        <source>Keyword</source>
+        <translation>Schlüsselwort</translation>
+    </message>
+    <message>
+        <source>Label</source>
+        <translation>Marke</translation>
+    </message>
+    <message>
+        <source>Variable</source>
+        <translation>Variable</translation>
+    </message>
+    <message>
+        <source>Operator</source>
+        <translation>Operator</translation>
+    </message>
+    <message>
+        <source>Hide command character</source>
+        <translation>&quot;Befehl verbergen&quot; Zeichen</translation>
+    </message>
+    <message>
+        <source>External command</source>
+        <translation>Externer Befehl</translation>
+    </message>
+</context>
 <context>
     <name>QextScintillaLexerCPP</name>
-    <message>
-        <source>White space</source>
-        <translation type="obsolete">Leerzeichen</translation>
-    </message>
-    <message>
-        <source>C style comment</source>
-        <translation type="obsolete">C Kommentar</translation>
-    </message>
-    <message>
-        <source>C++ style comment</source>
-        <translation type="obsolete">C++ Kommentar</translation>
-    </message>
-    <message>
-        <source>Doxygen aware C style comment</source>
-        <translation type="obsolete">Doxygen C Kommentar</translation>
-    </message>
     <message>
         <source>Number</source>
         <translation>Zahl</translation>
@@ -387,18 +430,6 @@
         <source>Unclosed string</source>
         <translation>Unbeendete Zeichenkette</translation>
     </message>
-    <message>
-        <source>Doxygen aware C++ style comment</source>
-        <translation type="obsolete">Doxygen C++ Kommentar</translation>
-    </message>
-    <message>
-        <source>Doxygen keyword</source>
-        <translation type="obsolete">Doxygen Schlüsselwort</translation>
-    </message>
-    <message>
-        <source>Doxygen keyword error</source>
-        <translation type="obsolete">Doxygen Schlüsselwortfehler</translation>
-    </message>
     <message>
         <source>Default</source>
         <translation>Standard</translation>
@@ -436,6 +467,73 @@
         <translation>Globale Klassen und typdefinitionen</translation>
     </message>
 </context>
+<context>
+    <name>QextScintillaLexerCSS</name>
+    <message>
+        <source>Default</source>
+        <translation>Standard</translation>
+    </message>
+    <message>
+        <source>Tag</source>
+        <translation>Tag</translation>
+    </message>
+    <message>
+        <source>Class selector</source>
+        <translation>Klassenselektor</translation>
+    </message>
+    <message>
+        <source>Pseudo-class</source>
+        <translation>Pseudoklasse</translation>
+    </message>
+    <message>
+        <source>Unknown pseudo-class</source>
+        <translation>Unbekannte Pseudoklasse</translation>
+    </message>
+    <message>
+        <source>Operator</source>
+        <translation>Operator</translation>
+    </message>
+    <message>
+        <source>CSS1 property</source>
+        <translation>CSS1 Eigenschaft</translation>
+    </message>
+    <message>
+        <source>Unknown property</source>
+        <translation>Unbekannte Eigenschaft</translation>
+    </message>
+    <message>
+        <source>Value</source>
+        <translation>Wert</translation>
+    </message>
+    <message>
+        <source>ID selector</source>
+        <translation>ID-Selektor</translation>
+    </message>
+    <message>
+        <source>Important</source>
+        <translation>Wichtig</translation>
+    </message>
+    <message>
+        <source>@-rule</source>
+        <translation>@-Regel</translation>
+    </message>
+    <message>
+        <source>Double-quoted string</source>
+        <translation>Zeichenkette in Anführungszeichen</translation>
+    </message>
+    <message>
+        <source>Single-quoted string</source>
+        <translation>Zeichenkette in Hochkommata</translation>
+    </message>
+    <message>
+        <source>CSS2 property</source>
+        <translation>CSS2 Eigenschaft</translation>
+    </message>
+    <message>
+        <source>Attribute</source>
+        <translation>Attribut</translation>
+    </message>
+</context>
 <context>
     <name>QextScintillaLexerCSharp</name>
     <message>
@@ -443,6 +541,37 @@
         <translation>Uninterpretierte Zeichenkette</translation>
     </message>
 </context>
+<context>
+    <name>QextScintillaLexerDiff</name>
+    <message>
+        <source>Default</source>
+        <translation>Standard</translation>
+    </message>
+    <message>
+        <source>Comment</source>
+        <translation>Kommentar</translation>
+    </message>
+    <message>
+        <source>Command</source>
+        <translation>Befehl</translation>
+    </message>
+    <message>
+        <source>Header</source>
+        <translation>Kopfzeilen</translation>
+    </message>
+    <message>
+        <source>Position</source>
+        <translation>Position</translation>
+    </message>
+    <message>
+        <source>Removed line</source>
+        <translation>Entfernte Zeile</translation>
+    </message>
+    <message>
+        <source>Added line</source>
+        <translation>Hinzugefügte Zeile</translation>
+    </message>
+</context>
 <context>
     <name>QextScintillaLexerHTML</name>
     <message>
@@ -896,6 +1025,171 @@
         <translation>Regulärer Ausdruck</translation>
     </message>
 </context>
+<context>
+    <name>QextScintillaLexerLua</name>
+    <message>
+        <source>Default</source>
+        <translation>Standard</translation>
+    </message>
+    <message>
+        <source>Comment</source>
+        <translation>Kommentar</translation>
+    </message>
+    <message>
+        <source>Line comment</source>
+        <translation>Zeilenkommentar</translation>
+    </message>
+    <message>
+        <source>Number</source>
+        <translation>Zahl</translation>
+    </message>
+    <message>
+        <source>Keyword</source>
+        <translation>Schlüsselwort</translation>
+    </message>
+    <message>
+        <source>String</source>
+        <translation>Zeichenkette</translation>
+    </message>
+    <message>
+        <source>Character</source>
+        <translation>Zeichen</translation>
+    </message>
+    <message>
+        <source>Literal string</source>
+        <translation>Uninterpretierte Zeichenkette</translation>
+    </message>
+    <message>
+        <source>Preprocessor</source>
+        <translation>Preprozessor</translation>
+    </message>
+    <message>
+        <source>Operator</source>
+        <translation>Operator</translation>
+    </message>
+    <message>
+        <source>Identifier</source>
+        <translation>Bezeichner</translation>
+    </message>
+    <message>
+        <source>Unclosed string</source>
+        <translation>Unbeendete Zeichenkette</translation>
+    </message>
+    <message>
+        <source>Basic functions</source>
+        <translation>Basisfunktionen</translation>
+    </message>
+    <message>
+        <source>String, table and maths functions</source>
+        <translation>Zeichenketten-, Tabelle- und mathematische Funktionen</translation>
+    </message>
+    <message>
+        <source>Coroutines, i/o and system facilities</source>
+        <translation>Koroutinen, I/O- und Systemfunktionen</translation>
+    </message>
+</context>
+<context>
+    <name>QextScintillaLexerMakefile</name>
+    <message>
+        <source>Default</source>
+        <translation>Standard</translation>
+    </message>
+    <message>
+        <source>Comment</source>
+        <translation>Kommentar</translation>
+    </message>
+    <message>
+        <source>Preprocessor</source>
+        <translation>Preprozessor</translation>
+    </message>
+    <message>
+        <source>Variable</source>
+        <translation>Variable</translation>
+    </message>
+    <message>
+        <source>Operator</source>
+        <translation>Operator</translation>
+    </message>
+    <message>
+        <source>Target</source>
+        <translation>Ziel</translation>
+    </message>
+    <message>
+        <source>Error</source>
+        <translation>Fehler</translation>
+    </message>
+</context>
+<context>
+    <name>QextScintillaLexerPOV</name>
+    <message>
+        <source>Default</source>
+        <translation>Standard</translation>
+    </message>
+    <message>
+        <source>Comment</source>
+        <translation>Kommentar</translation>
+    </message>
+    <message>
+        <source>Comment line</source>
+        <translation>Kommentarzeile</translation>
+    </message>
+    <message>
+        <source>Number</source>
+        <translation>Zahl</translation>
+    </message>
+    <message>
+        <source>Operator</source>
+        <translation>Operator</translation>
+    </message>
+    <message>
+        <source>Identifier</source>
+        <translation>Bezeichner</translation>
+    </message>
+    <message>
+        <source>String</source>
+        <translation>Zeichenkette</translation>
+    </message>
+    <message>
+        <source>Unclosed string</source>
+        <translation>Unbeendete Zeichenkette</translation>
+    </message>
+    <message>
+        <source>Directive</source>
+        <translation>Direktive</translation>
+    </message>
+    <message>
+        <source>Bad directive</source>
+        <translation>Ungültige Direktive</translation>
+    </message>
+    <message>
+        <source>Objects, CSG and appearance</source>
+        <translation>Objekte, CSG und Erscheinung</translation>
+    </message>
+    <message>
+        <source>Types, modifiers and items</source>
+        <translation>Typen, Modifizierer und Items</translation>
+    </message>
+    <message>
+        <source>Predefined identifiers</source>
+        <translation>Vordefinierter Bezeichner</translation>
+    </message>
+    <message>
+        <source>Predefined functions</source>
+        <translation>Vordefinierte Funktion</translation>
+    </message>
+    <message>
+        <source>User defined 1</source>
+        <translation>Nutzerdefiniert 1</translation>
+    </message>
+    <message>
+        <source>User defined 2</source>
+        <translation>Nutzerdefiniert 2</translation>
+    </message>
+    <message>
+        <source>User defined 3</source>
+        <translation>Nutzerdefiniert 3</translation>
+    </message>
+</context>
 <context>
     <name>QextScintillaLexerPerl</name>
     <message>
@@ -1006,13 +1300,36 @@
         <source>Quoted string (qw)</source>
         <translation>Zeichenkette (qw)</translation>
     </message>
+    <message>
+        <source>POD verbatim</source>
+        <translation>POD wörtlich</translation>
+    </message>
+</context>
+<context>
+    <name>QextScintillaLexerProperties</name>
+    <message>
+        <source>Default</source>
+        <translation>Standard</translation>
+    </message>
+    <message>
+        <source>Comment</source>
+        <translation>Kommentar</translation>
+    </message>
+    <message>
+        <source>Section</source>
+        <translation>Abschnitt</translation>
+    </message>
+    <message>
+        <source>Assignment</source>
+        <translation>Zuweisung</translation>
+    </message>
+    <message>
+        <source>Default value</source>
+        <translation>Standardwert</translation>
+    </message>
 </context>
 <context>
     <name>QextScintillaLexerPython</name>
-    <message>
-        <source>White space</source>
-        <translation type="obsolete">Leerzeichen</translation>
-    </message>
     <message>
         <source>Comment</source>
         <translation>Kommentar</translation>
@@ -1071,7 +1388,7 @@
     </message>
 </context>
 <context>
-    <name>QextScintillaLexerSQL</name>
+    <name>QextScintillaLexerRuby</name>
     <message>
         <source>Default</source>
         <translation>Standard</translation>
@@ -1081,8 +1398,59 @@
         <translation>Kommentar</translation>
     </message>
     <message>
-        <source>Line comment</source>
-        <translation>Zeilenkommentar</translation>
+        <source>Number</source>
+        <translation>Zahl</translation>
+    </message>
+    <message>
+        <source>Double-quoted string</source>
+        <translation>Zeichenkette in Anführungszeichen</translation>
+    </message>
+    <message>
+        <source>Single-quoted string</source>
+        <translation>Zeichenkette in Hochkommata</translation>
+    </message>
+    <message>
+        <source>Keyword</source>
+        <translation>Schlüsselwort</translation>
+    </message>
+    <message>
+        <source>Triple double-quoted string</source>
+        <translation>Zeichenkette in dreifachen Anführungszeichen</translation>
+    </message>
+    <message>
+        <source>Class name</source>
+        <translation>Klassenname</translation>
+    </message>
+    <message>
+        <source>Function or method name</source>
+        <translation>Funktions- oder Methodenname</translation>
+    </message>
+    <message>
+        <source>Operator</source>
+        <translation>Operator</translation>
+    </message>
+    <message>
+        <source>Identifier</source>
+        <translation>Bezeichner</translation>
+    </message>
+    <message>
+        <source>Comment block</source>
+        <translation>Kommentarblock</translation>
+    </message>
+    <message>
+        <source>Unclosed string</source>
+        <translation>Unbeendete Zeichenkette</translation>
+    </message>
+</context>
+<context>
+    <name>QextScintillaLexerSQL</name>
+    <message>
+        <source>Default</source>
+        <translation>Standard</translation>
+    </message>
+    <message>
+        <source>Comment</source>
+        <translation>Kommentar</translation>
     </message>
     <message>
         <source>Number</source>
@@ -1104,5 +1472,84 @@
         <source>Identifier</source>
         <translation>Bezeichner</translation>
     </message>
+    <message>
+        <source>Comment line</source>
+        <translation>Kommentarzeile</translation>
+    </message>
+    <message>
+        <source>JavaDoc style comment</source>
+        <translation>JavaDoc Kommentar</translation>
+    </message>
+    <message>
+        <source>Double-quoted string</source>
+        <translation>Zeichenkette in Anführungszeichen</translation>
+    </message>
+    <message>
+        <source>SQL*Plus keyword</source>
+        <translation>SQL*Plus Schlüsselwort</translation>
+    </message>
+    <message>
+        <source>SQL*Plus prompt</source>
+        <translation>SQL*Plus Eingabe</translation>
+    </message>
+    <message>
+        <source>SQL*Plus comment</source>
+        <translation>SQL*Plus Kommentar</translation>
+    </message>
+    <message>
+        <source># comment line</source>
+        <translation># Kommentarzeile</translation>
+    </message>
+    <message>
+        <source>JavaDoc keyword</source>
+        <translation>JavaDoc Schlüsselwort</translation>
+    </message>
+    <message>
+        <source>JavaDoc keyword error</source>
+        <translation>JavaDoc Schlüsselwortfehler</translation>
+    </message>
+    <message>
+        <source>User defined 1</source>
+        <translation>Nutzerdefiniert 1</translation>
+    </message>
+    <message>
+        <source>User defined 2</source>
+        <translation>Nutzerdefiniert 2</translation>
+    </message>
+    <message>
+        <source>User defined 3</source>
+        <translation>Nutzerdefiniert 3</translation>
+    </message>
+    <message>
+        <source>User defined 4</source>
+        <translation>Nutzerdefiniert 4</translation>
+    </message>
+</context>
+<context>
+    <name>QextScintillaLexerTeX</name>
+    <message>
+        <source>Default</source>
+        <translation>Standard</translation>
+    </message>
+    <message>
+        <source>Special</source>
+        <translation>Spezial</translation>
+    </message>
+    <message>
+        <source>Group</source>
+        <translation>Gruppe</translation>
+    </message>
+    <message>
+        <source>Symbol</source>
+        <translation>Symbol</translation>
+    </message>
+    <message>
+        <source>Command</source>
+        <translation>Befehl</translation>
+    </message>
+    <message>
+        <source>Text</source>
+        <translation>Text</translation>
+    </message>
 </context>
 </TS>
